/*
Copyright (c) 2000                      RIPE NCC


All Rights Reserved

Permission to use, copy, modify, and distribute this software and its
documentation for any purpose and without fee is hereby granted,
provided that the above copyright notice appear in all copies and that
both that copyright notice and this permission notice appear in
supporting documentation, and that the name of the author not be
used in advertising or publicity pertaining to distribution of the
software without specific, written prior permission.

THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING
ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS; IN NO EVENT SHALL
AUTHOR BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY
DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

/*
-------------------------------------------------------------------------------
Module Header
Filename          : RoutingInfo.h
Author            : Rene Wilhelm
Date              : 17-OCT-2000
Revised		  : 19-JUN-2000, count number of route changes
Description       : RoutingInfo class definition
Language Version  : C++
OSs Tested        : Solaris 2.6

RoutingInfo objects store the route vector information of measurements
between specific source and destination box.  

While processing TTM data files, the user adds information by calling
the Update() method. Once finished reading files, the summary 
data (max/min hops, #vectors) can be retrieved with corresponding
methods.

$Id: RoutingInfo.h,v 1.3 2001/06/19 13:47:49 wilhelm Exp $
-------------------------------------------------------------------------------
*/

#ifndef ROUTINGINFO_H
#define ROUTINGINFO_H

#include <stdlib.h>

class RoutingInfo {
private:
	int size;
	int *vectors;
	int entries;
	int flaps;
	int lastid;
	int maxhops;
	int minhops;
public:
	RoutingInfo();
	void Update(int vectorid, int nhops);
	void Reset();
	int GetMaxHops() {return maxhops;};
	int GetMinHops() {return minhops;};
	int GetEntries() {return entries;};
	int GetNumFlaps() {return flaps;};
	~RoutingInfo(){free(vectors);};
};

#endif
